@@ -1,14 +1,17 @@
 /*
- *  lexhead.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  lexhead.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
  *  ObjectProDSP is a trademark of Mountain Math Software.
  */
+/*  lexhead.h   */
+/*  Copyright 1989 Mountain Math Software  */
+/*  All Rights Reserved                    */
 #ifndef LEXHEAD_DOT_H
 #define LEXHEAD_DOT_H
-#include <iostream.h>
+#include <stream.h>
 
 #include "portable.h"
 #include "prsdrv.h"
