@@ -1,6 +1,6 @@
 /*
- *  netplot.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software. All rights reserved.
+ *  netplot.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software. All rights reserved.
  *  
  *  This file is part of ObjectProDSP, a tool for Digital Signal
  *  Processing design, development and implementation. It is free
@@ -51,6 +51,8 @@ class WidgetKit ;
 class LayoutKit ;
 class Requisition ;
 class MenuKeyboard ;
+class Canvas ;
+class Allocation;
 
 class NetworkDescriptionFull;
 class Style ;
@@ -74,6 +76,17 @@ class EdibleGlyph ; // Its easier to type then `EditableGlyph'
 
 declareEditLinearList(VerticalPosition)
 
+struct LastPosition {
+	Coord left ;
+	Coord right ;
+	Coord top ;
+	Coord bottom ;
+	LastPosition() ;
+	void set(const Allocation& a);
+	Coord center_x() const ;
+	Coord center_y() const ;
+};
+
 class VerticalGlyphs {
 	PolyGlyph * the_vbox ;
 	VerticalPosition_LinearList edible_graph ;
@@ -99,7 +112,7 @@ public:
 	EdibleGlyph * select_end() ;
 	VerticalPosition_LinearList& vertical_list() {return edible_graph;}
 	VerticalPosition * get(GlyphIndex ix);
-	GlyphIndex number() {return edible_graph.number();}
+	GlyphIndex number() const {return edible_graph.number();}
 
 	int scroll_mode();
 	int is_room_for(VerticalPosition &pos);
@@ -107,11 +120,12 @@ public:
 	GlyphIndex first_visible() const {return the_first_visible;}
 	void make_visible(EdibleGlyph * to_see);
 	void make_visible(GlyphIndex ix);
-	GlyphIndex is_visible(GlyphIndex ix); // returns -1 if not visible
-	GlyphIndex visible_size();
+	GlyphIndex is_visible(GlyphIndex ix) const; // returns -1 if not visible
+	GlyphIndex visible_size() const; 
 	EdibleGlyph * select(const char * name) ;
 	Coord height() const ;
 	void dump() ;
+	void draw_connect(Canvas*, const Allocation&) const ;
 };
 
 class NetGraph: public DspActiveHandler, public Observer {
@@ -130,6 +144,7 @@ class NetGraph: public DspActiveHandler, public Observer {
 	EdibleGlyph * the_label_selection ;
 	int prefer_mouse ;
 	int edit_flag ;
+	int do_show_label_links ;
 
 	Patch * patch ;
 	TopLevelWindow * the_window ;
@@ -160,6 +175,7 @@ public:
 	virtual void enter();
 	virtual void leave();
 
+	virtual void draw(Canvas*, const Allocation&) const ;
 
 	void make_body();
 	MenuKeyboard * build_menu(WidgetKit& kit, const LayoutKit& layout,
@@ -256,7 +272,7 @@ public:
 	void make_selection_visible();
 	GlyphIndex current_value();
 	void current_value(GlyphIndex ix);
-	GlyphIndex visible_size();
+	GlyphIndex visible_size() const;
 
 	virtual void act_select(const char * sel);
 	virtual void act_deselect();
@@ -266,6 +282,10 @@ public:
 	Coord height() const ;
 	NetworkGlyph * net_glyph() const { return description.net_glyph();}
 	void redraw_dim();
+
+	void show_label_links();
+	void clear_show_label_links();
+
 	void dump();
 };
 
@@ -275,6 +295,7 @@ class HorizontalPosition {
 public:
 	HorizontalPosition(EdibleGlyph * ed, GlyphIndex ix = -1);
 	virtual ~HorizontalPosition();
+	void draw_connect(Canvas*, const Allocation&) const ;
 	EdibleGlyph * cookie() const {return the_cookie;}
 	GlyphIndex index() const {return the_index;}
 	void index(GlyphIndex ix) {the_index = ix;}
@@ -304,12 +325,15 @@ public:
 	VerticalPosition(LayoutKit& layout,VerticalGlyphs& vert,GlyphIndex ix = -1);
 	virtual ~VerticalPosition();
 	HorizontalPosition * position(GlyphIndex ix) {return the_glyphs.get(ix);}
-	GlyphIndex number() {return the_glyphs.number();}
+	GlyphIndex number() const {return the_glyphs.number();}
 	void replace(HorizontalPosition * pos, GlyphIndex ix= -1) ;
 	void Remove(GlyphIndex ix, int redraw_flag=1);
 	void move(GlyphIndex new_index) {the_index = new_index;}
 	void insert(GlyphIndex after, EdibleGlyph *a, EdibleGlyph *b=0,
 		EdibleGlyph *c=0);
+
+	void draw_connect(Canvas*, const Allocation&) const ;
+
 	PolyGlyph * hbox() const {return the_hbox;}
 	GlyphIndex index() const {return the_index;}
 	void index(GlyphIndex ix) {the_index = ix;}
@@ -321,9 +345,10 @@ public:
 	const NetGraph& graph() const {return the_vertical_glyphs.graph();}
 	void redraw() {the_patch.redraw();}
 	Patch& patch() {return the_patch;}
-	int is_room_for(Glyph * a, Glyph * b=0, Glyph * c=0, Glyph * d=0) ;
+	int is_room_for(Glyph * a, Glyph * b=0, Glyph * c=0, Glyph * d=0,
+		Glyph * e=0, Glyph * f=0) ;
 	int is_room_for(EdibleGlyph * a, EdibleGlyph * b=0, EdibleGlyph * c=0,
-		EdibleGlyph * d=0) ;
+		EdibleGlyph * d=0, EdibleGlyph * e=0, EdibleGlyph * f=0) ;
 	void insert_horizontal(EdibleGlyph *a,EdibleGlyph *b=0, EdibleGlyph *c=0);
 	enum Termination {empty,open_link,unlinked_node,terminated_link};
 	Termination termination();
@@ -346,6 +371,7 @@ class EdibleGlyph {
 public:
 	EdibleGlyph(VerticalGlyphs::Flavor flavor);
 	virtual ~EdibleGlyph();
+	void draw_connect(Canvas*, const Allocation&) const ;
 	HorizontalPosition& horizontal_position() {return the_horizontal_position;}
 	VerticalPosition * vertical_position() const {return the_vertical_position;}
 	virtual void vertical_position(VerticalPosition * vertical)
@@ -392,12 +418,14 @@ class EdibleInputLabel : public DspActiveHandler , public EdibleGlyph {
 	char * text ;
 	int the_channel ;
 	EdibleInputLabel * the_next_input ;
+	LastPosition pos ;
 	Patch patch ;
 	void make_body(LayoutKit& layout);
 public:
 	EdibleInputLabel(TraverseObj& obj,  NodeDescription& node,int node_chan =0);
 	EdibleInputLabel(NetGraph& graph, EditLink& link);
 	virtual ~EdibleInputLabel() {delete text;}
+	void draw(Canvas*, const Allocation&) const ;
 	virtual Glyph * glyph() {return this;}
 	int channel() const {return the_channel;}
 	void next_input(EdibleInputLabel * lab) {the_next_input = lab;}
@@ -420,6 +448,9 @@ public:
 	void show_none();
 	virtual const char * name() {return text;}
 	virtual void dump();
+	void to_position(Coord& x, Coord& y) const;
+	void from_position(Coord& x, Coord& y) const;
+	void draw_from(Canvas * c) const ;
 };
 
 class EdibleOutputLabel : public DspActiveHandler , public EdibleGlyph {
@@ -430,11 +461,13 @@ class EdibleOutputLabel : public DspActiveHandler , public EdibleGlyph {
 	EdibleOutputLabel * the_next_output ;
 	NodeConnector * the_displayed_buffer ;
 	Patch patch ;
+	LastPosition pos ;
 	void make_body(LayoutKit& layout, WidgetKit& kit);
 public:
 	EdibleOutputLabel(TraverseObj& obj, NodeDescription& node);
 	EdibleOutputLabel(NetGraph& graph, EditLink& link, int buffer_chan);
 	virtual ~EdibleOutputLabel() {delete text;}
+	void draw(Canvas*, const Allocation&) const ;
 	virtual Glyph * glyph() {return this;}
 	int channel() const {return the_channel;}
 	int buffer_channel() const {return the_buffer_channel;}
@@ -462,6 +495,9 @@ public:
 	virtual const char * name() {return text;}
 	virtual void vertical_position(VerticalPosition * vertical);
 	virtual void dump();
+	void to_position(Coord& x, Coord& y) const;
+	void from_position(Coord& x, Coord& y) const;
+	void draw_to(Canvas *c, const NodeConnector * conn = 0) const ;
 };
 
 struct EditConnection {
@@ -507,6 +543,8 @@ class NodeGlyph: public ActiveHandler, public EdibleGlyph {
 	int * inputs_used ;
 	int * outputs_used ;
 
+	LastPosition pos ;
+
 	int input_available();
 	int output_available();
 	int buffer_available();
@@ -526,6 +564,9 @@ public:
 	NodeGlyph(NodeDescription& desc, WidgetKit& kit,
 		LayoutKit& layout, Style*);
 	virtual ~NodeGlyph();
+	virtual void draw(Canvas*, const Allocation&) const ;
+	void draw_connect_all(Canvas*, const Allocation&,
+		const NodeConnector *conn=0)const;
 	virtual void request (Requisition& r) const;
 	virtual void press(const Event&e) {graph().press(e);}
     virtual void release(const Event&e) {graph().release(e);}
@@ -587,6 +628,8 @@ public:
 	static const Coord hmargin_size ;
 	static const Coord vmargin_size ;
 	virtual void dump();
+	void to_position(Coord& x, Coord& y) const ;
+	void from_position(Coord& x, Coord& y) const;
 };
 
 class NodeConnector: public MonoGlyph, public EdibleGlyph {
@@ -599,6 +642,8 @@ class NodeConnector: public MonoGlyph, public EdibleGlyph {
 	Blinker * blinking_widget ;
 	static Coord min_width ;
 	char * the_name ;
+	LastPosition pos ;
+	
 
 	void make_body(LayoutKit& layout, WidgetKit &kit, Style *, int buf_size);
 	void add_from_index(Glyph * hbox,LayoutKit& layout, WidgetKit &kit) ;
@@ -610,6 +655,7 @@ public:
 	NodeConnector(NodeGlyph& glyph); // for editing
 	NodeConnector(EdibleOutputLabel& label); // for editing
 	virtual ~NodeConnector();
+	virtual void draw(Canvas*, const Allocation&) const ;
 	void ctor_from_graph();
 	const NodeDescription& node() const {return the_node;}
 	virtual Glyph * glyph() {return this;}
@@ -623,6 +669,8 @@ public:
 	virtual const char * name() {return the_name;}
 	int get_channel() const {return channel;}
 	virtual void dump();
+	void from_position(Coord& x, Coord& y) const;
+	void draw_connect_all(Canvas*, const Allocation&) const ;
 };
 
 
