@@ -1,16 +1,16 @@
 /*
- *  stdyacp.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  stdyacp.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
  *  ObjectProDSP is a trademark of Mountain Math Software.
  */
+/*  stdyacp.h   */
+/*  Copyright 1989 Mountain Math Software  */
+/*  All Rights Reserved                    */
 #ifndef STDYACP_DOT_H
 #define STDYACP_DOT_H
-class ostream ;
-extern ostream cerr ;
-
 void OutWhere(ostream& = cerr) ;
 void OutWhereX(int, ostream& = cerr);
 
