@@ -1,6 +1,6 @@
 /*
- *  innode.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  innode.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
@@ -18,10 +18,10 @@
 #include "ObjProGen/debug.h"
 #include "ObjProDSPcom/tarnod.h"
 class InputNode: public TargetNode {
-#line 105 "../innode.usr"
+#line 108 "../innode.usr"
  
 #include "ObjProDSPcom/innodex.h"
-#line 25 "/usrb/dist/ftp/opd-0.1/src/include/ObjProDSPtar/ObjProUsr/innode.h"
+#line 25 "/dist/opd_2/opd-0.2/src/include/ObjProDSPtar/ObjProUsr/innode.h"
 	const char *  FileName_1;
 	int16  Flags_2;
 	int32  DeltaOut_3;
