@@ -1,6 +1,6 @@
 /*
- *  packword.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  packword.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
@@ -26,7 +26,7 @@ class PackWord: public TargetNode {
 		{err_state=propagate_arith_type(in_channel,-GetInputWordSize()*
 			GetInputsPerOutput());}
 #endif
-#line 30 "/usrb/dist/ftp/opd-0.1/src/include/ObjProDSPtar/ObjProUsr/packword.h"
+#line 30 "/dist/opd_2/opd-0.2/src/include/ObjProDSPtar/ObjProUsr/packword.h"
 	int16  InputWordSize_1;
 	int16  InputsPerOutput_2;
 public:
