@@ -1,6 +1,6 @@
 /*
- *  readint.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  readint.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
@@ -10,7 +10,6 @@
 #ifndef READINT_DOT_H
 #define READINT_DOT_H
 #define __DSP_PP_TARGET_CODE__
-#include <iostream.h>
 #include <fstream.h>
 #include "ObjProArith/hrdarth.h"
 #include "ObjProDSPcom/inascii.h"
@@ -21,7 +20,7 @@
 #include "ObjProGen/debug.h"
 #include "ObjProDSPcom/tarnod.h"
 class ReadInt: public TargetNode {
-#line 48 "../readint.usr"
+#line 47 "../readint.usr"
  
 	ifstream * ReadIntFile ;
 	char * exp_name ;
@@ -29,7 +28,7 @@ class ReadInt: public TargetNode {
 	void open_f(int force_error) ;
 	ErrCode kernel(int k);
 	char * delete_name ;
-#line 33 "/usrb/dist/ftp/opd-0.1/src/include/ObjProDSPtar/ObjProUsr/readint.h"
+#line 32 "/dist/opd_2/opd-0.2/src/include/ObjProDSPtar/ObjProUsr/readint.h"
 	const char *  FileName_1;
 	int16  Flags_2;
 public:
