@@ -1,6 +1,6 @@
 /*
- *  menutab.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software. All rights reserved.
+ *  menutab.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software. All rights reserved.
  *  
  *  This file is part of ObjectProDSP, a tool for Digital Signal
  *  Processing design, development and implementation. It is free
@@ -2003,6 +2003,69 @@ static Menu VoiceStripOutInstanceParamMenu
 	("Menu of Parameters for `VoiceStripOut' Object Instance",VoiceStripOutInstanceParamMenuMenuLine,
 	0);
 
+extern MenuLine ZFde0NodeOptMenuMenuLine[];
+static Menu ZFde0NodeOptMenu
+	("Options for `ZFde0'",ZFde0NodeOptMenuMenuLine,
+	0);
+
+static DynamicMenu ZFde0InstancesMenu
+	("Select an Instance of `ZFde0' to describe or delete", 0,
+	1);
+
+extern MenuLine ZFde0InstanceAccessMenuMenuLine[];
+static Menu ZFde0InstanceAccessMenu
+	("Describe or delete an instance of  object `ZFde0'",ZFde0InstanceAccessMenuMenuLine,
+	0);
+
+extern MenuLine ZFde0ParamMenuMenuLine[];
+static Menu ZFde0ParamMenu
+	("Menu of Parameters for `ZFde0' Object",ZFde0ParamMenuMenuLine,
+	0);
+
+extern MenuLine ZFde0InstanceParamMenuMenuLine[];
+static Menu ZFde0InstanceParamMenu
+	("Menu of Parameters for `ZFde0' Object Instance",ZFde0InstanceParamMenuMenuLine,
+	0);
+
+extern MenuLine ZFde1NodeOptMenuMenuLine[];
+static Menu ZFde1NodeOptMenu
+	("Options for `ZFde1'",ZFde1NodeOptMenuMenuLine,
+	0);
+
+static DynamicMenu ZFde1InstancesMenu
+	("Select an Instance of `ZFde1' to describe or delete", 0,
+	1);
+
+extern MenuLine ZFde1InstanceAccessMenuMenuLine[];
+static Menu ZFde1InstanceAccessMenu
+	("Describe or delete an instance of  object `ZFde1'",ZFde1InstanceAccessMenuMenuLine,
+	0);
+
+extern MenuLine ZFde1ParamMenuMenuLine[];
+static Menu ZFde1ParamMenu
+	("Menu of Parameters for `ZFde1' Object",ZFde1ParamMenuMenuLine,
+	0);
+
+extern MenuLine ZFde1VariableMenuMenuLine[];
+static Menu ZFde1VariableMenu
+	("Menu of Variables for ZFde1 Object",ZFde1VariableMenuMenuLine,
+	0);
+
+extern MenuLine ZFde1InstanceParamMenuMenuLine[];
+static Menu ZFde1InstanceParamMenu
+	("Menu of Parameters for `ZFde1' Object Instance",ZFde1InstanceParamMenuMenuLine,
+	0);
+
+extern MenuLine ZFde1InstanceVariableMenuMenuLine[];
+static Menu ZFde1InstanceVariableMenu
+	("Menu of Variables for ZFde1 Object Instance",ZFde1InstanceVariableMenuMenuLine,
+	0);
+
+extern MenuLine ZFde1SetInstanceVariableMenuMenuLine[];
+static Menu ZFde1SetInstanceVariableMenu
+	("Menu of Variables for ZFde1 Object Instance",ZFde1SetInstanceVariableMenuMenuLine,
+	0);
+
 OrphanedMenus TheOrphanedMenus[] = {
 	{"SelectDisplayNodeStrMemberDescribe", &SelectDisplayNodeStrMemberDescribe},
 	{"SelectDisplayNodeStrMemberExecute", &SelectDisplayNodeStrMemberExecute},
@@ -2254,6 +2317,16 @@ DynamicMenuInfo TheRemoteDynamicMenuTable[] = {
 	"Select this instance of `VoiceStripOut'",
 	MenuTypeMenu, (void *) &VoiceStripOutInstanceAccessMenu},
 	"VoiceStripOutInstancesMenu"	},
+	{&ZFde0InstancesMenu,
+		{ 0,
+	"Select this instance of `ZFde0'",
+	MenuTypeMenu, (void *) &ZFde0InstanceAccessMenu},
+	"ZFde0InstancesMenu"	},
+	{&ZFde1InstancesMenu,
+		{ 0,
+	"Select this instance of `ZFde1'",
+	MenuTypeMenu, (void *) &ZFde1InstanceAccessMenu},
+	"ZFde1InstancesMenu"	},
 	0
 };
 
