@@ -1,14 +1,20 @@
 /*
- *  menuprsl.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  menuprsl.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
  *  ObjectProDSP is a trademark of Mountain Math Software.
  */
+/*  menuprsl.h   */
+/*  Copyright 1989 Mountain Math Software  */
+/*  All Rights Reserved                    */
 #ifndef MENUPRSL_DOT_H
 #define MENUPRSL_DOT_H
 #include <string.h>
+#ifdef __NT_VC__
+#include <io.h>
+#endif
 #include "portable.h"
 #include "stdyac.h"
 #include "text.h"
