@@ -1,11 +1,14 @@
 /*
- *  menuprsy.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  menuprsy.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
  *  ObjectProDSP is a trademark of Mountain Math Software.
  */
+/*  menuprsy.h   */
+/*  Copyright 1989 Mountain Math Software  */
+/*  All Rights Reserved                    */
 #include "portable.h"
 #define YTAB_DOT_H
 #include "menuprsl.h"
@@ -15,6 +18,9 @@
 #include "parammen.h"
 #include "yacoper.h"
 #include "objinit.h"
+#ifdef __NT_VC__
+#include <malloc.h>
+#endif
 
 
 Value * AddToWordString(Value *,const char * ,int = 1);
