@@ -1,13 +1,16 @@
 /*
- *  genmenu.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  genmenu.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
  *  ObjectProDSP is a trademark of Mountain Math Software.
  */
+/*  genmenu.h   */
+/*  Copyright 1989 Mountain Math Software  */
+/*  All Rights Reserved                    */
 void WriteMenuData(/* const char * , const char * , */ const char * NodeName,
-	class NodeParameterList *, class Description *);
+	class NodeParameterList *, struct Description *);
 
 void EmitHelpLine(class MofStream * Stream, class TextFragmentList * Text) ;
 void CloseMenuFile();
