@@ -1,11 +1,14 @@
 /*
- *  mknodel.h from ObjectProDSP 0.1
- *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
+ *  mknodel.h from ObjectProDSP 0.2
+ *  Copyright (C) 1994 1995, Mountain Math Software, All rights reserved.
  *  Licensed for free use and distribution under version 2 of the Gnu General
  *  Public License. Please see file COPYING for details and restrictions.
  *  
  *  ObjectProDSP is a trademark of Mountain Math Software.
  */
+/*  mknodel.h   */
+/*  Copyright 1989 Mountain Math Software  */
+/*  All Rights Reserved                    */
 #ifndef MKNODEL_DOT_H
 #define MKNODEL_DOT_H
 
@@ -13,5 +16,8 @@
 // #define class struct
 	/* makes many C++ headers compatible with standard c */
 #include "mknodelx.h"
+#ifdef __NT_VC__
+#include <io.h>
+#endif
 
 #endif /* #ifdef MKNODEL_DOT_H */
